# coding: utf-8

# flake8: noqa

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.10   3Di core release: 2.0.10  deployed on:  09:44AM (UTC) on July 02, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

from openapi_client.aio import rest as rest_iets
from openapi_client import *


# import ApiClient
rest = rest_iets
from openapi_client.aio.api_client import ApiClient

